@@ -7,12 +7,12 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-04-25'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 sub meta {
     +{
         v => 1,
-        summary => 'Check that an array has unique elements, using List::Util\'s uniqstr()',
+        summary => 'Check that an array has unique elements, using List::Util\'s uniqstr() (synonym for uniq())',
         target_type => 'array',
         might_fail => 1,
         args => {
@@ -61,7 +61,7 @@ sub filter {
 }
 
 1;
-# ABSTRACT: Check that an array has unique elements, using List::Util's uniqstr()
+# ABSTRACT: Check that an array has unique elements, using List::Util's uniqstr() (synonym for uniq())
 
 __END__
 
@@ -71,11 +71,11 @@ __END__
 
 =head1 NAME
 
-Data::Sah::Filter::perl::Array::check_uniqstr - Check that an array has unique elements, using List::Util's uniqstr()
+Data::Sah::Filter::perl::Array::check_uniqstr - Check that an array has unique elements, using List::Util's uniqstr() (synonym for uniq())
 
 =head1 VERSION
 
-This document describes version 0.016 of Data::Sah::Filter::perl::Array::check_uniqstr (from Perl distribution Data-Sah-Filter), released on 2023-04-25.
+This document describes version 0.017 of Data::Sah::Filter::perl::Array::check_uniqstr (from Perl distribution Data-Sah-Filter), released on 2023-04-25.
 
 =head1 SYNOPSIS
 
